@@ -8,7 +8,7 @@
 
 #include <QTest>
 
-#include <kmime_header_parsing.h>
+#include "kmime_header_parsing.h"
 
 using namespace KMime;
 
