@@ -8,7 +8,7 @@
 
 #include "rfc2231test.h"
 
-#include <kmime_util.h>
+#include "kmime_util.h"
 #include <kmime_codecs.cpp>
 #include <QDebug>
 using namespace KMime;
